/* $Id: ListCharFilter.java 343 2007-09-09 20:51:43Z hohwille $
 * Copyright (c) The m-m-m Team, Licensed under the Apache License, Version 2.0
 * http://www.apache.org/licenses/LICENSE-2.0 */
package net.sf.mmm.util.filter;

/**
 * This is an implementation of the {@link CharFilter} interface that
 * {@link #accept(char) filters} characters according to a
 * {@link ListCharFilter#ListCharFilter(boolean, char...) given} blacklist or
 * whitelist.
 * 
 * @author Joerg Hohwiller (hohwille at users.sourceforge.net)
 */
public class ListCharFilter implements CharFilter {

  /** @see #accept(char) */
  private boolean blacklist;

  /** @see #accept(char) */
  private final char[] chars;

  /**
   * The constructor.
   * 
   * @param accept - if <code>true</code> exactly the chars given by
   *        <code>charArray</code> are accepted (whitelist), if
   *        <code>false</code> exactly these chars are NOT accepted
   *        (blacklist).
   * @param charArray are the chars to accept or to reject.
   */
  public ListCharFilter(boolean accept, char... charArray) {

    super();
    this.chars = charArray;
    this.blacklist = !accept;
  }

  /**
   * {@inheritDoc}
   */
  public boolean accept(char c) {

    for (char currentChar : this.chars) {
      if (c == currentChar) {
        // if blacklist we return false because we found a disallowed char,
        // else we found an accepted char from the whitelist...
        return !this.blacklist;
      }
    }
    // the char was NOT found!
    // if blacklist -> return true because c is NOT blacklisted
    // if whitelist -> return false because c is NOT in the whitelist
    return this.blacklist;
  }

}
